/**
 * http组件
 */
const axios = require('axios');

const Log = require('./log');

module.exports = {
  async http(opts) {
    const method = opts.method || 'get';
    const url = opts.url || '';
    const responseType = opts.responseType || 'json';
    const timeout = opts.timeout || 0;
    const proxy = opts.proxy || {};
    const headers = opts.headers || {};
    const notThrowError = opts.notThrowError || false;
    const maxContentLength = opts.maxContentLength || 2000;
    const dealError = opts.dealError;

    const config = {
      url,
      headers,
      method,
      responseType,
      timeout,
      maxContentLength,
    };

    if (method === 'get') {
      config.params = opts.data || {};
    } else {
      config.data = opts.data || {};
    }

    if (Object.keys(proxy).length !== 0) {
      config.proxy = proxy;
    }

    try {
      const result = await axios(config);
      return result.data;
    } catch (err) {
      if (notThrowError) {
        Log.error(`${url} ${err}`);

        if (dealError) {
          await dealError(err);
        }

        return '';
      }

      throw new Error(`${url} ${err}`);
    }
  },

  async post(opts) {
    opts = opts || {};
    opts.method = 'post';
    const result = await this.http(opts);
    return result;
  },

  async get(opts) {
    opts = opts || {};
    opts.method = 'get';
    const result = await this.http(opts);
    return result;
  },

  async put(opts) {
    opts = opts || {};
    opts.method = 'put';
    const result = await this.http(opts);
    return result;
  },

  async del(opts) {
    opts = opts || {};
    opts.method = 'delete';
    const result = await this.http(opts);
    return result;
  },
};
